==> evolution-1.3.5.zip: evolution-1.3.5/manager/actions/help/02Documentation.php <==
<?php
if(IN_MANAGER_MODE!="true") die("<b>INCLUDE_ORDERING_ERROR</b><br /><br />Please use the MODX Content Manager instead of accessing this file directly.");
?>

<div class="sectionHeader"><?php echo $_lang['documentation']; ?></div><div class="sectionBody">
    <table border="0" cellspacing="0" cellpadding="0">
        <tr><td><a href="http://www.evolution-docs.com/" target="_blank">What is EVO?</a></td><td></td><td>Official EVO documentation</td></tr>
        <tr><td><a href="https://evo.im/" target="_blank">evo.im</a></td><td></td><td>Home of EVO</td></tr>
        <tr><td><a href="http://forum.evolution-cms.com/" target="_blank">EVO Forums</a></td><td></td><td>General support & discussions</td></tr>
        <tr><td><a href="http://docs.evolution-cms.com/" target="_blank">docs.evolution-cms.com</a></td><td><a href="https://translate.google.com/translate?hl=en&sl=auto&tl=en&u=http://docs.evolution-cms.com/" target="_blank">Google Translate</a></td><td>Further documentation</td></tr>
        <tr><td><a href="http://saniock.com/modx-evolution/developer/api.html" target="_blank">API Reference</a></td><td><a href="https://translate.google.com/translate?hl=en&sl=auto&tl=en&u=http://saniock.com/modx-evolution/developer/api.html" target="_blank">Google Translate</a></td><td>Further documentation</td></tr>
        <tr><td><a href="http://modx.im/" target="_blank">MODX.im</a></td><td><a href="https://translate.google.com/translate?hl=en&sl=auto&tl=en&u=http://modx.im/" target="_blank">Google Translate</a></td><td>Russian community</td></tr>
    </table>
</div>

==> evolution-1.4.1.zip: evolution-1.4.1/manager/actions/help/02Documentation.php <==
<?php
if( ! defined('IN_MANAGER_MODE') || IN_MANAGER_MODE !== true) {
    die("<b>INCLUDE_ORDERING_ERROR</b><br /><br />Please use the EVO Content Manager instead of accessing this file directly.");
}
?>

<div class="sectionHeader"><?php echo $_lang['documentation']; ?></div><div class="sectionBody">
    <table border="0" cellspacing="0" cellpadding="0">
        <tr><td><a href="http://www.evolution-docs.com/" target="_blank">What is EVO?</a></td><td></td><td>Official EVO documentation</td></tr>
        <tr><td><a href="https://evo.im/" target="_blank">evo.im</a></td><td></td><td>Home of EVO</td></tr>
        <tr><td><a href="http://forum.evolution-cms.com/" target="_blank">EVO Forums</a></td><td></td><td>General support & discussions</td></tr>
        <tr><td><a href="http://docs.evolution-cms.com/" target="_blank">docs.evolution-cms.com</a></td><td><a href="https://translate.google.com/translate?hl=en&sl=auto&tl=en&u=http://docs.evolution-cms.com/" target="_blank">Google Translate</a></td><td>Further documentation</td></tr>
        <tr><td><a href="http://saniock.com/modx-evolution/developer/api.html" target="_blank">API Reference</a></td><td><a href="https://translate.google.com/translate?hl=en&sl=auto&tl=en&u=http://saniock.com/modx-evolution/developer/api.html" target="_blank">Google Translate</a></td><td>Further documentation</td></tr>
        <tr><td><a href="http://modx.im/" target="_blank">MODX.im</a></td><td><a href="https://translate.google.com/translate?hl=en&sl=auto&tl=en&u=http://modx.im/" target="_blank">Google Translate</a></td><td>Russian community</td></tr>
    </table>
</div>
